| Title: | Repbox analysis of stata scripts in reproduction packages |
|---|---|
| Description: | Repbox analysis of stata scripts in reproduction packages |
| Authors: | Sebastian Kranz (Ulm University) |
| Maintainer: | Sebastian Kranz <[email protected]> |
| License: | GPL >= 3.0 |
| Version: | 0.1.0 |
| Built: | 2026-06-03 08:32:35 UTC |
| Source: | https://github.com/repboxr/repboxStata |